Helpers class

Constructors

Helpers(LuaBindings bindings)

Properties

bindings → LuaBindings
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getArgs(Pointer<lua_State> L) → List
Extract arguments from Lua stack into a Dart List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pushValue(Pointer<lua_State> L, dynamic value) → void
Push a Dart value onto Lua stack
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited