lua_Debug class final

Inheritance
Implemented types
Available extensions

Constructors

lua_Debug()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
currentline ↔ int
getter/setter pair
event ↔ int
getter/setter pair
ftransfer ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
i_ci ↔ Pointer<CallInfo>
getter/setter pair
istailcall ↔ int
getter/setter pair
isvararg ↔ int
getter/setter pair
lastlinedefined ↔ int
getter/setter pair
linedefined ↔ int
getter/setter pair
name ↔ Pointer<Char>
getter/setter pair
namewhat ↔ Pointer<Char>
getter/setter pair
nparams ↔ int
getter/setter pair
ntransfer ↔ int
getter/setter pair
nups ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
short_src ↔ Array<Char>
getter/setter pair
source ↔ Pointer<Char>
getter/setter pair
srclen ↔ int
getter/setter pair
what ↔ Pointer<Char>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited