LuaRuntime class

Constructors

LuaRuntime()

Properties

hashCode → int
The hash code for this object.
no setterinherited
L ↔ Pointer<lua_State>
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerFunction(String name, Pointer<NativeFunction<Int32 Function(Pointer<lua_State>)>> fn) → void
run(String code) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

lastPrintOutput ↔ String
getter/setter pair
lua ↔ LuaBindings
getter/setter pair